@@ -42,8 +42,17 @@ async def bybit() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    res_linear = await market_http.get_instruments_info(category="linear")
-    df_linear = to_dataframe(res_linear["result"]["list"]) if "list" in res_linear.get("result", {}) else pl.DataFrame()
+    linear_data = []
+    cursor = None
+    while True:
+        res_linear = await market_http.get_instruments_info(category="linear", cursor=cursor)
+        linear_data.extend(res_linear["result"]["list"])
+        if res_linear["result"]["nextPageCursor"] == "":
+            break
+        cursor = res_linear["result"]["nextPageCursor"]
+
+    df_linear = to_dataframe(linear_data)
+
     for market in df_linear.iter_rows(named=True):
         base = clean_symbol_and_strip_number(market["baseCoin"])
         quote = market["quoteCoin"]
@@ -676,8 +685,17 @@ async def zoomex() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    res_linear = await market_http.get_instruments_info(category="linear")
-    df_linear = to_dataframe(res_linear["result"]["list"]) if "list" in res_linear.get("result", {}) else pl.DataFrame()
+    linear_data = []
+    cursor = None
+    while True:
+        res_linear = await market_http.get_instruments_info(category="linear", cursor=cursor)
+        linear_data.extend(res_linear["result"]["list"])
+        if res_linear["result"]["nextPageCursor"] == "":
+            break
+        cursor = res_linear["result"]["nextPageCursor"]
+
+    df_linear = to_dataframe(linear_data)
+    
     for market in df_linear.iter_rows(named=True):
         base = clean_symbol_and_strip_number(market["baseCoin"])
         quote = market["quoteCoin"]
@@ -706,7 +724,7 @@ async def zoomex() -> pl.DataFrame:
                 price_precision=market["priceFilter"]["tickSize"],
                 size_precision=market["lotSizeFilter"]["qtyStep"],
                 min_size=market["lotSizeFilter"]["minOrderQty"],
-                min_notional=market["lotSizeFilter"].get("minNotionalValue", "0"),
+                min_notional="5",
             )
         )
 
@@ -768,4 +786,4 @@ async def zoomex() -> pl.DataFrame:
             )
         )
     markets = [market.to_dict() for market in markets]
-    return pl.DataFrame(markets)
\ No newline at end of file
+    return pl.DataFrame(markets)
